Changelog
---------


-----------
Version 0.4
-----------

Released on 2017-11-28

- Distinction between pakbus address and node in the pakbus protocol.
- Minor bug correction to can visualize help on python 3.x.
- Allow seconds in settime.

-----------
Version 0.3
-----------

Released on 2014-03-26.

- Bug correction about communication with NL115, NL120 and NL200 modules using "CSI/O" serial port.
- Support python 3.3 and 3.4 

-----------
Version 0.2
-----------

Released on 2012-07-26.

- Fixed a bug related to update command (on Windows)
- Used UTC datetime
- Decoded pakbus packet properly
- Other minor bugs fixed

-----------
Version 0.1
-----------

Released on 2012-07-18.

First properly tagged release.
